@@ -9,6 +9,7 @@ class CassandraConnection(object):
         self.hosts = options.get('HOST').split(',')
         self.keyspace = options.get('NAME')
         self.options = options.get('OPTIONS', {})
+        self.connection_options = self.options.get('connection', {})
         self.setup()
 
     def setup(self):
@@ -16,11 +17,7 @@ class CassandraConnection(object):
             # already connected
             return
 
-        connection.setup(
-            self.hosts,
-            self.keyspace,
-            **self.options.get('connection', {})
-        )
+        connection.setup(self.hosts, self.keyspace, **self.connection_options)
 
     def commit(self):
         pass
